aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/template/compile.php
diff options
context:
space:
mode:
authorOleg Pudeyev <oleg@bsdpower.com>2012-11-08 12:21:06 -0500
committerOleg Pudeyev <oleg@bsdpower.com>2012-11-17 16:42:40 -0500
commit44d6dc4c4ccf969fd3d84f3b39bfd24ecd3a3f9d (patch)
tree5dd030f606400f049141dbc9b086e6288b6dd0b7 /phpBB/includes/template/compile.php
parent0a29312d830c65dc293822c291bf2efd6f93a29b (diff)
downloadforums-44d6dc4c4ccf969fd3d84f3b39bfd24ecd3a3f9d.tar
forums-44d6dc4c4ccf969fd3d84f3b39bfd24ecd3a3f9d.tar.gz
forums-44d6dc4c4ccf969fd3d84f3b39bfd24ecd3a3f9d.tar.bz2
forums-44d6dc4c4ccf969fd3d84f3b39bfd24ecd3a3f9d.tar.xz
forums-44d6dc4c4ccf969fd3d84f3b39bfd24ecd3a3f9d.zip
[feature/template-events] Convert a single style name to array of them.
This allows template code to know the entire style hierarchy for templates being rendered. PHPBB3-9550
Diffstat (limited to 'phpBB/includes/template/compile.php')
-rw-r--r--phpBB/includes/template/compile.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/phpBB/includes/template/compile.php b/phpBB/includes/template/compile.php
index c2762bfd59..76ad2317c9 100644
--- a/phpBB/includes/template/compile.php
+++ b/phpBB/includes/template/compile.php
@@ -36,17 +36,17 @@ class phpbb_template_compile
* Constructor.
*
* @param bool $allow_php Whether PHP code will be allowed in templates (inline PHP code, PHP tag and INCLUDEPHP tag)
* @param string $style_name Name of style to which the template being compiled belongs
* @param phpbb_style_resource_locator $locator Resource locator
* @param string $phpbb_root_path Path to phpBB root directory
* @param phpbb_extension_manager $extension_manager Extension manager to use for finding template fragments in extensions; if null, template hooks will not be invoked
* @param phpbb_user $user Current user
*/
- public function __construct($allow_php, $style_name, $locator, $phpbb_root_path, $extension_manager = null, $user = null)
+ public function __construct($allow_php, $style_names, $locator, $phpbb_root_path, $extension_manager = null, $user = null)
{
$this->filter_params = array(
'allow_php' => $allow_php,
- 'style_name' => $style_name,
+ 'style_names' => $style_names,
'locator' => $locator,
'phpbb_root_path' => $phpbb_root_path,
'extension_manager' => $extension_manager,
@@ -36,17 +36,17 @@ class phpbb_template_compile
*
* @param bool $allow_php Whether PHP code will be allowed in templates (inline PHP code, PHP tag and INCLUDEPHP tag)
- * @param string $style_name Name of style to which the template being compiled belongs
+ * @param array $style_names Name of style to which the template being compiled belongs and parents in style tree order
* @param phpbb_style_resource_locator $locator Resource locator
* @param string $phpbb_root_path Path to phpBB root directory